==> nextcloud-28.0.14.zip: nextcloud/lib/l10n/cy_GB.js <==
OC.L10N.register(
    "lib",
    {
    "Files" : "Ffeiliau",
    "today" : "heddiw",
    "yesterday" : "ddoe",
    "last month" : "mis diwethaf",
    "last year" : "y llynedd",
    "seconds ago" : "eiliad yn ôl",
    "Apps" : "Pecynnau",
    "Settings" : "Gosodiadau",
    "Log out" : "Allgofnodi",
    "Email" : "E-bost",
    "Phone" : "Ffôn",
    "Website" : "Gwefan",
    "Address" : "Cyfeiriad",
    "About" : "Ynghylch",
    "Set an admin password." : "Gosod cyfrinair y gweinyddwr.",
    "Click the button below to open it." : "Cliciwch ar y botwm isod i'w agor.",
    "%1$s via %2$s" : "%1$s trwy %2$s",
    "Could not find category \"%s\"" : "Methu canfod categori \"%s\"",
    "Sunday" : "Sul",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "Sun." : "Sul.",
    "Mon." : "Llun.",
    "Tue." : "Maw.",
    "Wed." : "Mer.",
    "Thu." : "Iau.",
    "Fri." : "Gwe.",
    "Sat." : "Sad.",
    "January" : "Ionawr",
    "February" : "Chwefror",
    "March" : "Mawrth",
    "April" : "Ebrill",
    "May" : "Mai",
    "June" : "Mehefin",
    "July" : "Gorffennaf",
    "August" : "Awst",
    "September" : "Medi",
    "October" : "Hydref",
    "November" : "Tachwedd",
    "December" : "Rhagfyr",
    "Jan." : "Ion.",
    "Feb." : "Chwe.",
    "Mar." : "Maw.",
    "Apr." : "Ebr.",
    "May." : "Mai.",
    "Jun." : "Meh.",
    "Jul." : "Gor.",
    "Aug." : "Aws.",
    "Sep." : "Med.",
    "Oct." : "Hyd.",
    "Nov." : "Tach.",
    "Dec." : "Rhag.",
    "Application is not enabled" : "Nid yw'r pecyn wedi'i alluogi",
    "Authentication error" : "Gwall dilysu",
    "Token expired. Please reload page." : "Tocyn wedi dod i ben. Ail-lwythwch y dudalen.",
    "Summary" : "Crynodeb",
    "Translate" : "Cyfieithu",
    "Help" : "Cymorth",
    "Users" : "Defnyddwyr",
    "Oracle username and/or password not valid" : "Enw a/neu gyfrinair Oracle annilys",
    "PostgreSQL username and/or password not valid" : "Enw a/neu gyfrinair PostgreSQL annilys",
    "Set an admin username." : "Creu enw defnyddiwr i'r gweinyddwr.",
    "Open »%s«" : "Agor »%s«"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-29.0.2.zip: nextcloud/lib/l10n/cy_GB.js <==
OC.L10N.register(
    "lib",
    {
    "Files" : "Ffeiliau",
    "today" : "heddiw",
    "yesterday" : "ddoe",
    "last month" : "mis diwethaf",
    "last year" : "y llynedd",
    "seconds ago" : "eiliad yn ôl",
    "Apps" : "Pecynnau",
    "Settings" : "Gosodiadau",
    "Log out" : "Allgofnodi",
    "Email" : "E-bost",
    "Phone" : "Ffôn",
    "Website" : "Gwefan",
    "Address" : "Cyfeiriad",
    "About" : "Ynghylch",
    "Set an admin password." : "Gosod cyfrinair y gweinyddwr.",
    "Open »%s«" : "Agor »%s«",
    "%1$s via %2$s" : "%1$s trwy %2$s",
    "Click the button below to open it." : "Cliciwch ar y botwm isod i'w agor.",
    "Could not find category \"%s\"" : "Methu canfod categori \"%s\"",
    "Sunday" : "Sul",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "Sun." : "Sul.",
    "Mon." : "Llun.",
    "Tue." : "Maw.",
    "Wed." : "Mer.",
    "Thu." : "Iau.",
    "Fri." : "Gwe.",
    "Sat." : "Sad.",
    "January" : "Ionawr",
    "February" : "Chwefror",
    "March" : "Mawrth",
    "April" : "Ebrill",
    "May" : "Mai",
    "June" : "Mehefin",
    "July" : "Gorffennaf",
    "August" : "Awst",
    "September" : "Medi",
    "October" : "Hydref",
    "November" : "Tachwedd",
    "December" : "Rhagfyr",
    "Jan." : "Ion.",
    "Feb." : "Chwe.",
    "Mar." : "Maw.",
    "Apr." : "Ebr.",
    "May." : "Mai.",
    "Jun." : "Meh.",
    "Jul." : "Gor.",
    "Aug." : "Aws.",
    "Sep." : "Med.",
    "Oct." : "Hyd.",
    "Nov." : "Tach.",
    "Dec." : "Rhag.",
    "Application is not enabled" : "Nid yw'r pecyn wedi'i alluogi",
    "Authentication error" : "Gwall dilysu",
    "Token expired. Please reload page." : "Tocyn wedi dod i ben. Ail-lwythwch y dudalen.",
    "Summary" : "Crynodeb",
    "Help" : "Cymorth",
    "Users" : "Defnyddwyr",
    "Oracle username and/or password not valid" : "Enw a/neu gyfrinair Oracle annilys",
    "PostgreSQL username and/or password not valid" : "Enw a/neu gyfrinair PostgreSQL annilys",
    "Set an admin username." : "Creu enw defnyddiwr i'r gweinyddwr."
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
